"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RouteService = void 0;
const domain_1 = require("../../domain");
class RouteService {
    // eslint-disable-next-line no-useless-constructor
    constructor(stageConfigService, expressions) {
        this.stageConfigService = stageConfigService;
        this.expressions = expressions;
    }
    eval(source, clauseInfo) {
        const contextInfo = this.getContextInfo(clauseInfo);
        if (source.condition === undefined)
            return true;
        return this.expressions.eval(source.condition, contextInfo);
    }
    getContextInfo(clauseInfo) {
        return {
            entity: clauseInfo.entity,
            action: clauseInfo.action,
            read: clauseInfo.action === domain_1.ObservableAction.select,
            write: clauseInfo.action !== domain_1.ObservableAction.select,
            dml: clauseInfo.action !== domain_1.ObservableAction.ddl,
            ddl: clauseInfo.action === domain_1.ObservableAction.ddl
        };
    }
    getSource(clauseInfo, stage) {
        const contextInfo = this.getContextInfo(clauseInfo);
        const _stage = this.stageConfigService.get(stage);
        for (const i in _stage.sources) {
            const source = _stage.sources[i];
            if (source.condition === undefined) {
                return source.name;
            }
            else {
                const result = this.expressions.eval(source.condition, contextInfo);
                if (result) {
                    return source.name;
                }
            }
        }
        throw new domain_1.SchemaError(`Undefined data source on stage ${_stage.name}`);
    }
}
exports.RouteService = RouteService;
//# sourceMappingURL=routeService.js.map